.. _f2py-win-pgi:

===============================
F2PY and PGI Fortran on Windows
===============================

A variant of these are part of the so called "classic" Flang, however, 
as classic Flang requires a custom LLVM and compilation from sources.

.. warning::

	Since the proprietary compilers are no longer available for
	usage they are not recommended and will not be ported to the
	new ``f2py`` CLI. 
	


.. note::

	**As of November 2021**

	As of 29-01-2022, `PGI compiler toolchains`_ have been superseded by the Nvidia
  	HPC SDK, with no `native Windows support`_.

.. _PGI compiler toolchains: https://www.pgroup.com/index.html
.. _native Windows support: https://developer.nvidia.com/nvidia-hpc-sdk-downloads#collapseFour
